==========================================
NOVA MVVM library documentation
==========================================

Thank you for your interest in developing interactive applications
for `NOVA <https://nova.ornl.gov/>`_. This documentation will guide you through the process of creating a new application and deploying it to NOVA.

Interactive applications for NOVA are developed with the `Trame Framework <https://kitware.github.io/trame/>`_. This framework allows you to build full web applications in Python.

To make it easier to get started, we provide a UI package, :code:`nova-trame`, that should help streamline your development process. All examples in this documentation are based upon this package.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   core_concepts/index
   examples/index
   api_reference
